@@ -3,7 +3,7 @@ ldapobject.py - wraps class _ldap.LDAPObject
 
 See http://www.python-ldap.org/ for details.
 
-\$Id: ldapobject.py,v 1.105 2009/10/23 09:17:37 stroeder Exp $
+\$Id: ldapobject.py,v 1.108 2010/02/26 08:57:29 stroeder Exp $
 
 Compability:
 - Tested with Python 2.0+ but should work with Python 1.5.x
@@ -284,20 +284,6 @@ class SimpleLDAPObject:
   def delete_s(self,dn):
     return self.delete_ext_s(dn,None,None)
 
-  def manage_dsa_it(self,enable,critical=0):
-    """
-    manage_dsa_it() -> None
-    Enable or disable manageDSAit mode (see draft-zeilenga-ldap-namedref)
-    """
-    all_server_ctrls = [
-      c
-      for c in self.get_option(ldap.OPT_SERVER_CONTROLS) or []
-      if c.controlType!='2.16.840.1.113730.3.4.2'
-    ]    
-    if enable:
-      all_server_ctrls.append(LDAPControl('2.16.840.1.113730.3.4.2',critical,None))
-    self.set_option(ldap.OPT_SERVER_CONTROLS,all_server_ctrls)
-  
   def modify_ext(self,dn,modlist,serverctrls=None,clientctrls=None):
     """
     modify_ext(dn, modlist[,serverctrls=None[,clientctrls=None]]) -> int
@@ -378,8 +364,8 @@ class SimpleLDAPObject:
     """
     return self._ldap_call(self._l.rename,dn,newrdn,newsuperior,delold,EncodeControlTuples(serverctrls),EncodeControlTuples(clientctrls))
 
-  def rename_s(self,dn,newrdn,newsuperior=None,delold=1):
-    msgid = self.rename(dn,newrdn,newsuperior,delold)
+  def rename_s(self,dn,newrdn,newsuperior=None,delold=1,serverctrls=None,clientctrls=None):
+    msgid = self.rename(dn,newrdn,newsuperior,delold,serverctrls,clientctrls)
     return self.result(msgid,all=1,timeout=self.timeout)
 
   def result(self,msgid=ldap.RES_ANY,all=1,timeout=None):
@@ -831,90 +817,6 @@ class ReconnectLDAPObject(SimpleLDAPObject):
     return self._apply_method_s(SimpleLDAPObject.whoami_s,*args,**kwargs)
 
 
-class SmartLDAPObject(ReconnectLDAPObject):
-  """
-  Mainly the __init__() method does some smarter things
-  like negotiating the LDAP protocol version and calling
-  LDAPObject.start_tls_s().
-  """
-
-  def __init__(
-    self,uri,
-    trace_level=0,trace_file=None,trace_stack_limit=5,
-    retry_max=1,retry_delay=60.0,
-    who='',cred='',
-    start_tls=1,
-    tls_cacertfile=None,tls_cacertdir=None,
-    tls_clcertfile=None,tls_clkeyfile=None,
-  ):
-    """
-    Return LDAPObject instance by opening LDAP connection to
-    LDAP host specified by LDAP URL.
-
-    Unlike ldap.initialize() this function also trys to bind
-    explicitly with the bind DN and credential given as parameter,
-    probe the supported LDAP version and trys to use
-    StartTLS extended operation if this was specified.
-
-    Parameters like ReconnectLDAPObject.__init__() with these
-    additional arguments:
-    who,cred
-        The Bind-DN and credential to use for simple bind
-        right after connecting.
-    start_tls
-        Determines if StartTLS extended operation is tried
-        on a LDAPv3 server and if the LDAP URL scheme is ldap:.
-        If LDAP URL scheme is not ldap: (e.g. ldaps: or ldapi:)
-        this parameter is ignored.
-        0       Don't use StartTLS ext op
-        1       Try StartTLS ext op but proceed when unavailable
-        2       Try StartTLS ext op and re-raise exception if it fails
-    tls_cacertfile
-
-    tls_clcertfile
-
-    tls_clkeyfile
-
-    """
-    # Initialize LDAP connection
-    ReconnectLDAPObject.__init__(
-      self,uri,
-      trace_level=trace_level,
-      trace_file=trace_file,
-      trace_stack_limit=trace_stack_limit,
-      retry_max=retry_max,
-      retry_delay=retry_delay
-    )
-    # Set protocol version to LDAPv3
-    self.protocol_version = ldap.VERSION3
-    self.started_tls = 0
-    try:
-      self.simple_bind_s(who,cred)
-    except ldap.PROTOCOL_ERROR:
-      # Drop connection completely
-      self.unbind_s() ; del self._l
-      self._l = ldap.functions._ldap_function_call(_ldap.initialize,self._uri)
-      self.protocol_version = ldap.VERSION2
-      self.simple_bind_s(who,cred)
-    # Try to start TLS if requested
-    if start_tls>0 and uri[:5]=='ldap:':
-      if self.protocol_version>=ldap.VERSION3:
-        try:
-          self.start_tls_s()
-        except (ldap.PROTOCOL_ERROR,ldap.CONNECT_ERROR):
-          if start_tls>=2:
-            # Application does not accept clear-text connection
-            # => re-raise exception
-            raise
-        else:
-          self.started_tls = 1
-      else:
-        if start_tls>=2:
-          raise ValueError,"StartTLS extended operation only possible on LDAPv3+ server!"
-    if self.protocol_version==ldap.VERSION2 or (who and cred):
-      self.simple_bind_s(who,cred)
-
-
 # The class called LDAPObject will be used as default for
 # ldap.open() and ldap.initialize()
 LDAPObject = SimpleLDAPObject
