@@ -1,8 +1,8 @@
 /*
  * errors that arise from ldap use
  * Most errors become their own exception
- * See http://python-ldap.sourceforge.net for details.
- * $Id: errors.c,v 1.17 2008/06/14 16:03:38 stroeder Exp $ */
+ * See http://www.python-ldap.org/ for details.
+ * $Id: errors.c,v 1.21 2009/04/17 12:19:09 stroeder Exp $ */
 
 #include "common.h"
 #include "errors.h"
@@ -16,10 +16,14 @@ LDAPexception_class;
 
 #define LDAP_ERROR_MIN          LDAP_REFERRAL_LIMIT_EXCEEDED
 
-#ifdef LDAP_ASSERTION_FAILED
-#define LDAP_ERROR_MAX          LDAP_ASSERTION_FAILED
-#elif
-#define LDAP_ERROR_MAX          LDAP_OTHER
+#ifdef LDAP_PROXIED_AUTHORIZATION_DENIED
+	#define LDAP_ERROR_MAX          LDAP_PROXIED_AUTHORIZATION_DENIED
+#else
+	#ifdef LDAP_ASSERTION_FAILED
+		#define LDAP_ERROR_MAX          LDAP_ASSERTION_FAILED
+	#else
+		#define LDAP_ERROR_MAX          LDAP_OTHER
+	#endif
 #endif
 
 #define LDAP_ERROR_OFFSET       -LDAP_ERROR_MIN
@@ -48,20 +52,25 @@ LDAPerror( LDAP*l, char*msg )
 		return NULL;
 	}
 	else {
-		int errnum;
+		int errnum, opt_errnum;
 		PyObject *errobj;
 		PyObject *info;
 		PyObject *str;
 
 		char *matched, *error;
-		if (ldap_get_option(l, LDAP_OPT_ERROR_NUMBER, &errnum) < 0)
-			errobj = LDAPexception_class;	/* unknown error XXX */
-		else
-			errobj = errobjects[errnum+LDAP_ERROR_OFFSET];
-		
+
+		opt_errnum = ldap_get_option(l, LDAP_OPT_ERROR_NUMBER, &errnum);
+		if (opt_errnum != LDAP_OPT_SUCCESS)
+			errnum = opt_errnum;
+
 		if (errnum == LDAP_NO_MEMORY)
 			return PyErr_NoMemory();
 
+		if (errnum >= LDAP_ERROR_MIN && errnum <= LDAP_ERROR_MAX)
+			errobj = errobjects[errnum+LDAP_ERROR_OFFSET];
+		else
+			errobj = LDAPexception_class;
+		
 		info = PyDict_New();
 		if (info == NULL)
 			return NULL;
@@ -204,4 +213,8 @@ LDAPinit_errors( PyObject*d ) {
 	seterrobj(ASSERTION_FAILED);
 #endif
 
+#ifdef LDAP_PROXIED_AUTHORIZATION_DENIED
+  seterrobj(PROXIED_AUTHORIZATION_DENIED);
+#endif
+
 }
